@@ -18,14 +18,14 @@
 
 from typing import Union, Optional, AsyncGenerator
 
+import pyrogram
 from pyrogram import raw
 from pyrogram import types
-from pyrogram.scaffold import Scaffold
 
 
-class GetChatAdminInviteLinks(Scaffold):
+class GetChatAdminInviteLinks:
     async def get_chat_admin_invite_links(
-        self,
+        self: "pyrogram.Client",
         chat_id: Union[int, str],
         admin_id: Union[int, str],
         revoked: bool = False,
@@ -70,7 +70,7 @@ class GetChatAdminInviteLinks(Scaffold):
         offset_link = None
 
         while True:
-            r = await self.send(
+            r = await self.invoke(
                 raw.functions.messages.GetExportedChatInvites(
                     peer=await self.resolve_peer(chat_id),
                     admin_id=await self.resolve_peer(admin_id),
