@@ -18,16 +18,16 @@
 
 from typing import Optional
 
-from pyrogram import types
-from pyrogram.scaffold import Scaffold
+import pyrogram
+from pyrogram import types, enums
 
 
-class EditInlineCaption(Scaffold):
+class EditInlineCaption:
     async def edit_inline_caption(
-        self,
+        self: "pyrogram.Client",
         inline_message_id: str,
         caption: str,
-        parse_mode: Optional[str] = object,
+        parse_mode: Optional["enums.ParseMode"] = None,
         reply_markup: "types.InlineKeyboardMarkup" = None
     ) -> bool:
         """Edit the caption of inline media messages.
@@ -39,12 +39,9 @@ class EditInlineCaption(Scaffold):
             caption (``str``):
                 New caption of the media message.
 
-            parse_mode (``str``, *optional*):
+            parse_mode (:obj:`~pyrogram.enums.ParseMode`, *optional*):
                 By default, texts are parsed using both Markdown and HTML styles.
                 You can combine both syntaxes together.
-                Pass "markdown" or "md" to enable Markdown-style parsing only.
-                Pass "html" to enable HTML-style parsing only.
-                Pass None to completely disable style parsing.
 
             reply_markup (:obj:`~pyrogram.types.InlineKeyboardMarkup`, *optional*):
                 An InlineKeyboardMarkup object.
@@ -56,7 +53,7 @@ class EditInlineCaption(Scaffold):
             .. code-block:: python
 
                 # Bots only
-                app.edit_inline_caption(inline_message_id, "new media caption")
+                await app.edit_inline_caption(inline_message_id, "new media caption")
         """
         return await self.edit_inline_text(
             inline_message_id=inline_message_id,
