@@ -1,5 +1,5 @@
 #  Pyrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
+#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
 #
 #  This file is part of Pyrogram.
 #
@@ -18,14 +18,14 @@
 
 from typing import Union, List
 
+import pyrogram
 from pyrogram import raw
 from pyrogram import types
-from pyrogram.scaffold import Scaffold
 
 
-class VotePoll(Scaffold):
+class VotePoll:
     async def vote_poll(
-        self,
+        self: "pyrogram.Client",
         chat_id: Union[int, str],
         message_id: id,
         options: Union[int, List[int]]
@@ -50,13 +50,13 @@ class VotePoll(Scaffold):
         Example:
             .. code-block:: python
 
-                app.vote_poll(chat_id, message_id, 6)
+                await app.vote_poll(chat_id, message_id, 6)
         """
 
         poll = (await self.get_messages(chat_id, message_id)).poll
         options = [options] if not isinstance(options, list) else options
 
-        r = await self.send(
+        r = await self.invoke(
             raw.functions.messages.SendVote(
                 peer=await self.resolve_peer(chat_id),
                 msg_id=message_id,
