@@ -97,6 +97,9 @@ class User(Object, Update):
         is_support (``bool``, *optional*):
             True, if this user is part of the Telegram support team.
 
+        is_premium (``bool``, *optional*):
+            True, if this user is a premium user.
+
         first_name (``str``, *optional*):
             User's or bot's first name.
 
@@ -118,6 +121,9 @@ class User(Object, Update):
         language_code (``str``, *optional*):
             IETF language tag of the user's language.
 
+        emoji_status (:obj:`~pyrogram.types.EmojiStatus`, *optional*):
+            Emoji status.
+
         dc_id (``int``, *optional*):
             User's or bot's assigned DC (data center). Available only in case the user has set a public profile photo.
             Note that this information is approximate; it is based on where Telegram stores a user profile pictures and
@@ -156,13 +162,15 @@ class User(Object, Update):
         is_scam: bool = None,
         is_fake: bool = None,
         is_support: bool = None,
+        is_premium: bool = None,
         first_name: str = None,
         last_name: str = None,
-        status: str = None,
+        status: "enums.UserStatus" = None,
         last_online_date: datetime = None,
         next_offline_date: datetime = None,
         username: str = None,
         language_code: str = None,
+        emoji_status: Optional[str] = None,
         dc_id: int = None,
         phone_number: str = None,
         photo: "types.ChatPhoto" = None,
@@ -181,6 +189,7 @@ class User(Object, Update):
         self.is_scam = is_scam
         self.is_fake = is_fake
         self.is_support = is_support
+        self.is_premium = is_premium
         self.first_name = first_name
         self.last_name = last_name
         self.status = status
@@ -188,6 +197,7 @@ class User(Object, Update):
         self.next_offline_date = next_offline_date
         self.username = username
         self.language_code = language_code
+        self.emoji_status = emoji_status
         self.dc_id = dc_id
         self.phone_number = phone_number
         self.photo = photo
@@ -218,11 +228,13 @@ class User(Object, Update):
             is_scam=user.scam,
             is_fake=user.fake,
             is_support=user.support,
+            is_premium=user.premium,
             first_name=user.first_name,
             last_name=user.last_name,
             **User._parse_status(user.status, user.bot),
             username=user.username,
             language_code=user.lang_code,
+            emoji_status=types.EmojiStatus._parse(client, user.emoji_status),
             dc_id=getattr(user.photo, "dc_id", None),
             phone_number=user.phone,
             photo=types.ChatPhoto._parse(client, user.photo, user.id, user.access_hash),
